==> knt_ui-1.0.0.tar.gz: lib/src/widget/knt_bottom_nav.dart <==
import 'package:easy_localization/easy_localization.dart';
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'package:flutter_svg/flutter_svg.dart';

import '../../generated/colors.gen.dart';
import '../model/tab_icon.dart';

class KntBottomNav extends StatefulWidget {
  final ValueNotifier<int> onTabChanged;
  final List<TabIcon> icons;
  final double? iconSize;
  final double? iconSpacing;
  final BorderRadius? borderRadius;

  const KntBottomNav({
    Key? key,
    required this.onTabChanged,
    this.icons = const [],
    this.iconSize,
    this.iconSpacing,
    this.borderRadius,
  }) : super(key: key);

  @override
  _KntBottomNavState createState() => _KntBottomNavState();
}

class _KntBottomNavState extends State<KntBottomNav> {
  late ValueNotifier<int> _onTabChanged;

  @override
  void initState() {
    super.initState();
    _onTabChanged = widget.onTabChanged;
  }

  void _onTappedTab(int index) {
    _onTabChanged.value = index;
  }

  @override
  Widget build(BuildContext context) {
    final borderRadius = widget.borderRadius ??
        BorderRadius.only(
          topLeft: Radius.circular(20.w),
          topRight: Radius.circular(20.w),
        );
    return Container(
      height: 68.h,
      decoration: BoxDecoration(
        color: Colors.transparent,
        borderRadius: borderRadius,
        boxShadow: [
          BoxShadow(
            color: Colors.black12,
            offset: Offset(-1.w, -1.w),
            blurRadius: 4.w,
          ),
        ],
      ),
      child: ClipRRect(
        borderRadius: borderRadius,
        child: ValueListenableBuilder<int>(
          valueListenable: _onTabChanged,
          builder: (context, tabIndex, child) {
            return BottomNavigationBar(
              currentIndex: tabIndex,
              selectedItemColor: ColorName.jungleGreen,
              unselectedItemColor: ColorName.doveGray,
              selectedLabelStyle: TextStyle(
                color: ColorName.jungleGreen,
                fontSize: 12.sp,
                height: 16.sp / 12.sp,
                fontWeight: FontWeight.w700,
              ),
              unselectedLabelStyle: TextStyle(
                color: ColorName.doveGray,
                fontSize: 12.sp,
                height: 16.sp / 12.sp,
                fontWeight: FontWeight.w400,
              ),
              onTap: _onTappedTab,
              showUnselectedLabels: true,
              type: BottomNavigationBarType.fixed,
              items: widget.icons.map((icon) {
                final iconSize = widget.iconSize ?? 24.w;
                final paddingBottom = widget.iconSpacing ?? 4.w;
                return BottomNavigationBarItem(
                  activeIcon: Padding(
                    padding: EdgeInsets.only(bottom: paddingBottom),
                    child: SvgPicture.asset(
                      icon.activeImagePath,
                      width: iconSize,
                      height: iconSize,
                      fit: BoxFit.fill,
                    ),
                  ),
                  icon: Padding(
                    padding: EdgeInsets.only(bottom: paddingBottom),
                    child: SvgPicture.asset(
                      icon.inactiveImagePath,
                      width: iconSize,
                      height: iconSize,
                      fit: BoxFit.fill,
                    ),
                  ),
                  label: icon.localeKeyTitle.tr(),
                );
              }).toList(),
            );
          },
        ),
      ),
    );
  }
}

class KntBottomNavScaffold extends StatefulWidget {
  final ValueNotifier<int> onTabChanged;
  final PreferredSizeWidget? appBar;
  final List<Widget> tabs;
  final List<TabIcon> icons;
  final Widget? floatingActionButton;
  final FloatingActionButtonLocation? floatingActionButtonLocation;
  final FloatingActionButtonAnimator? floatingActionButtonAnimator;
  final BorderRadius? navBorderRadius;

  const KntBottomNavScaffold({
    Key? key,
    required this.onTabChanged,
    this.appBar,
    this.tabs = const [],
    this.icons = const [],
    this.floatingActionButton,
    this.floatingActionButtonLocation,
    this.floatingActionButtonAnimator,
    this.navBorderRadius,
  })  : assert(tabs.length == icons.length,
            'Length of [tabs] and [icons] must be matched'),
        assert(tabs.length > 0, 'Must have 1 tab at least'),
        super(key: key);

  @override
  _KntBottomNavScaffoldState createState() => _KntBottomNavScaffoldState();
}

class _KntBottomNavScaffoldState extends State<KntBottomNavScaffold> {
  late ValueNotifier<int> _onTabChanged;

  @override
  void initState() {
    super.initState();
    _onTabChanged = widget.onTabChanged;
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: widget.appBar,
      bottomNavigationBar: KntBottomNav(
        icons: widget.icons,
        onTabChanged: _onTabChanged,
        borderRadius: widget.navBorderRadius,
      ),
      floatingActionButton: widget.floatingActionButton,
      floatingActionButtonLocation: widget.floatingActionButtonLocation,
      floatingActionButtonAnimator: widget.floatingActionButtonAnimator,
      body: SafeArea(
        top: false,
        child: Stack(
          children: [
            ValueListenableBuilder<int>(
              valueListenable: _onTabChanged,
              builder: (context, tabIndex, child) {
                return IndexedStack(
                  index: tabIndex,
                  children: widget.tabs,
                );
              },
            ),
          ],
        ),
      ),
    );
  }
}

==> knt_ui-1.1.1.tar.gz: lib/src/widget/knt_bottom_nav.dart <==
import 'package:flutter/material.dart';
import 'package:knt_ui/knt_ui.dart';

import '../../generated/colors.gen.dart';

class KntBottomNav extends StatefulWidget {
  final ValueNotifier<int> onTabChanged;
  final List<TabIcon> icons;
  final double? iconSize;
  final double? iconSpacing;
  final BorderRadius? borderRadius;
  final Color? selectedItemColor;
  final Color? unselectedItemColor;

  const KntBottomNav({
    Key? key,
    required this.onTabChanged,
    this.icons = const [],
    this.iconSize,
    this.iconSpacing,
    this.borderRadius,
    this.selectedItemColor,
    this.unselectedItemColor,
  }) : super(key: key);

  @override
  _KntBottomNavState createState() => _KntBottomNavState();
}

class _KntBottomNavState extends State<KntBottomNav> {
  late ValueNotifier<int> _onTabChanged;

  @override
  void initState() {
    super.initState();
    _onTabChanged = widget.onTabChanged;
  }

  void _onTappedTab(int index) {
    _onTabChanged.value = index;
  }

  @override
  Widget build(BuildContext context) {
    final borderRadius = widget.borderRadius ??
        BorderRadius.only(
          topLeft: Radius.circular(20.w),
          topRight: Radius.circular(20.w),
        );
    return Container(
      height: 68.h,
      decoration: BoxDecoration(
        color: Colors.transparent,
        borderRadius: borderRadius,
        boxShadow: [
          BoxShadow(
            color: Colors.black12,
            offset: Offset(-1.w, -1.w),
            blurRadius: 4.w,
          ),
        ],
      ),
      child: ClipRRect(
        borderRadius: borderRadius,
        child: ValueListenableBuilder<int>(
          valueListenable: _onTabChanged,
          builder: (context, tabIndex, child) {
            return BottomNavigationBar(
              currentIndex: tabIndex,
              selectedItemColor:
                  widget.selectedItemColor ?? ColorName.jungleGreen,
              unselectedItemColor:
                  widget.unselectedItemColor ?? ColorName.doveGray,
              selectedLabelStyle: TextStyle(
                color: widget.selectedItemColor ?? ColorName.jungleGreen,
                fontSize: 12.sp,
                height: 16.sp / 12.sp,
                fontWeight: FontWeight.w700,
              ),
              unselectedLabelStyle: TextStyle(
                color: widget.unselectedItemColor ?? ColorName.doveGray,
                fontSize: 12.sp,
                height: 16.sp / 12.sp,
                fontWeight: FontWeight.w400,
              ),
              onTap: _onTappedTab,
              showUnselectedLabels: true,
              type: BottomNavigationBarType.fixed,
              items: widget.icons.map((icon) {
                final iconSize = widget.iconSize ?? 24.w;
                final paddingBottom = widget.iconSpacing ?? 4.w;
                return BottomNavigationBarItem(
                  activeIcon: Padding(
                    padding: EdgeInsets.only(bottom: paddingBottom),
                    child: KntImage.assets(
                      uri: icon.activeImagePath,
                      width: iconSize,
                      height: iconSize,
                      fit: BoxFit.fill,
                    ),
                  ),
                  icon: Padding(
                    padding: EdgeInsets.only(bottom: paddingBottom),
                    child: KntImage.assets(
                      uri: icon.inactiveImagePath,
                      width: iconSize,
                      height: iconSize,
                      fit: BoxFit.fill,
                    ),
                  ),
                  label: icon.localeKeyTitle.tr(),
                );
              }).toList(),
            );
          },
        ),
      ),
    );
  }
}

class KntBottomNavScaffold extends StatefulWidget {
  final ValueNotifier<int> onTabChanged;
  final PreferredSizeWidget? appBar;
  final List<Widget> tabs;
  final List<TabIcon> icons;
  final Widget? floatingActionButton;
  final FloatingActionButtonLocation? floatingActionButtonLocation;
  final FloatingActionButtonAnimator? floatingActionButtonAnimator;
  final BorderRadius? navBorderRadius;
  final bool lightTheme;

  const KntBottomNavScaffold({
    Key? key,
    required this.onTabChanged,
    this.appBar,
    this.tabs = const [],
    this.icons = const [],
    this.floatingActionButton,
    this.floatingActionButtonLocation,
    this.floatingActionButtonAnimator,
    this.navBorderRadius,
    this.lightTheme = true,
  })  : assert(tabs.length == icons.length,
            'Length of [tabs] and [icons] must be matched'),
        assert(tabs.length > 0, 'Must have 1 tab at least'),
        super(key: key);

  @override
  _KntBottomNavScaffoldState createState() => _KntBottomNavScaffoldState();
}

class _KntBottomNavScaffoldState extends State<KntBottomNavScaffold> {
  late ValueNotifier<int> _onTabChanged;

  @override
  void initState() {
    super.initState();
    _onTabChanged = widget.onTabChanged;
  }

  @override
  Widget build(BuildContext context) {
    final content = Scaffold(
      appBar: widget.appBar,
      bottomNavigationBar: KntBottomNav(
        icons: widget.icons,
        onTabChanged: _onTabChanged,
        borderRadius: widget.navBorderRadius,
      ),
      floatingActionButton: widget.floatingActionButton,
      floatingActionButtonLocation: widget.floatingActionButtonLocation,
      floatingActionButtonAnimator: widget.floatingActionButtonAnimator,
      body: SafeArea(
        top: false,
        child: ValueListenableBuilder<int>(
          valueListenable: _onTabChanged,
          builder: (context, tabIndex, child) {
            return IndexedStack(
              index: tabIndex,
              children: widget.tabs,
            );
          },
        ),
      ),
    );
    return widget.lightTheme
        ? KntWhiteStatusBarPage(page: content)
        : KntBlackStatusBarPage(page: content);
  }
}
